import { useEffect, useState } from 'react'
import type { Appwrite, Models } from 'appwrite/types/sdk'

export type UseAccountResult<Preferences> = {
  account: Models.User<Preferences> | undefined,
  isLoading: boolean,
  error: any,
}

export default function useAccount<Preferences>(appwrite: Appwrite): UseAccountResult<Preferences> {
  const [account, setAccount] = useState<Models.User<Preferences> | undefined>(undefined)
  const [isLoading, setIsLoading] = useState<boolean>(true)
  const [error, setError] = useState<any>()

  useEffect(() => {
    appwrite
      .account
      .get()
      // @ts-ignore
      .then(setAccount)
      .catch(setError)
      .finally(() => setIsLoading(false))

    return appwrite.subscribe('account', e => {
      console.log('update', e)
      setAccount(e.payload as Models.User<Preferences>)
    })
  }, [])

  return {
    account,
    isLoading,
    error,
  }
}